@@ -7,23 +7,9 @@ require "xdg"
 require "yaml"
 
 module Tmuxinator
-  SUPPORTED_TMUX_VERSIONS = [
-    1.5,
-    1.6,
-    1.7,
-    1.8,
-    1.9,
-    2.0,
-    2.1,
-    2.2,
-    2.3,
-    2.4,
-    2.5,
-    2.6,
-    2.7
-  ].freeze
 end
 
+require "tmuxinator/tmux_version"
 require "tmuxinator/util"
 require "tmuxinator/deprecations"
 require "tmuxinator/wemux_support"
